
Icon = class( Turbine.UI.Window )

function Icon:Constructor(data, parent, size, left, top, opacity)
	Turbine.UI.Window.Constructor( self )
	
	self.data = data
	self.opacity = opacity
	self.skill = FindSkill(data["name"])
	

	self:SetParent(parent)
	self:SetPosition(left, top)
	self:SetSize(size, size)
	self:SetMouseVisible(false)	
	self:SetOpacity(opacity)
	
	if self.skill ~= nil then
	
		self:SetVisible(true)
		self.resetTime = self.skill:GetResetTime()
		
		if data["font"] then
			self.font = findfont(data["font"])
		else
			self.font = findfont(15)
		end
		if data["alignment"] then
			self.alignment = findalignment(data["alignment"])
		else
			self.alignment = findalignment(9)
		end
		if data["thresholdFont"] then
			self.tfont = findfont(data["thresholdFont"])
		else
			self.tfont = findfont(19)
		end
		if data["thresholdAlignment"] then
			self.talignment = findalignment(data["thresholdAlignment"])
		else
			self.talignment = findalignment(5)
		end
		if data["thresholdColor"] then
			self.tcolor = Turbine.UI.Color(data["thresholdColor"]["R"],data["thresholdColor"]["G"],data["thresholdColor"]["B"])
		else
			self.tcolor = Turbine.UI.Color.Red
		end
		if data["thresholdValue"] then
			self.thresholdValue = data["thresholdValue"]
		else
			self.thresholdValue = 6
		end
		

		self.popUp = Turbine.UI.Window()
	
		if data["showpopup"] then
	
			
			self.popUp:SetMouseVisible(false)	
			self.popUp:SetPosition(-50,-50)
			self.popUp:SetSize(32,32)
			self.popUp:SetBackground(self.skill:GetSkillInfo():GetIconImageID())
			self.popUp:SetStretchMode(1)
			self.popUp:SetSize(data["popupsize"], data["popupsize"])
			self.popUp:SetZOrder(1)
			
			if data["popupanchor"] then
				self.popUp:SetParent(self)
			else
				self.popUp:SetParent(anchor)
			end
			
		end
			
		self.icon = Turbine.UI.Window()
		self.icon:SetMouseVisible(false)	
		self.icon:SetParent(self)
		self.icon:SetOpacity(self.opacity)
		self.icon:SetSize(32, 32)
		self.icon:SetBackground(self.skill:GetSkillInfo():GetIconImageID())
		self.icon:SetStretchMode(1)
		self.icon:SetSize(size, size)
		self.icon:SetZOrder(2)
		--self.icon:SetBlendMode(Turbine.UI.BlendMode.Grayscale)
		
		self.textBG = Turbine.UI.Window()
		self.textBG:SetMouseVisible(false)	
		self.textBG:SetParent(self)
		self.textBG:SetSize(32, 32)
		self.textBG:SetStretchMode(1)
		self.textBG:SetSize(size, size)
		self.textBG:SetZOrder(3)
		
		self.text = Turbine.UI.Label()
		self.text:SetMouseVisible(false)	
		self.text:SetParent(self.textBG)
		self.text:SetSize(32, 32)
		self.text:SetFont(self.font)
		self.text:SetTextAlignment(self.alignment)
		self.text:SetFontStyle(Turbine.UI.FontStyle.Outline)
		self.text:SetZOrder(5)
		
		if data["showoffcd"] then
			
			self.icon:SetVisible(true)
			self.textBG:SetVisible(true)
		
		end

		self.skill.ResetTimeChanged = function()
		
			self.popUp:SetVisible(false)
			
			if self.data["resetTimer"] == 0 then
		
				self.resetTime = self.skill:GetResetTime()
				
			else
			
				self.resetTime = self.data["resetTimer"]+Turbine.Engine.GetGameTime()
			
			end
			
			self:SetWantsUpdates(true)
		
		end
	
		if self.resetTime ~= -1 then

			if data["showoncd"] then
				self.icon:SetVisible(false)
				self.textBG:SetVisible(false)
			end

			self:SetWantsUpdates(true)
		
		end
	
	end

end



function Icon:Update()

	local timeLeft = self.resetTime-Turbine.Engine.GetGameTime()

	if timeLeft ~= -1 then
	
		if timeLeft < 0 then
		
			self.icon:SetOpacity(self.opacity)
			self.text:SetText("")
			self.resetTime = -1
			self:SetWantsUpdates(false)
			
			if self.data["showpopup"] then
				self.popUp:SetVisible(false)
			end
			
			if self.data["showoffcd"] == false then

				self.icon:SetVisible(false)
				self.textBG:SetVisible(false)
			
			else

				self.icon:SetVisible(true)
				self.textBG:SetVisible(true)
						
			end
		
		else
		
			if self.data["showpopup"] and timeLeft < 1 then

				local size = (2*self.data["popupsize"]*timeLeft)+self:GetWidth()
				local pos = ((-1)*self.data["popupsize"])*timeLeft

				self.popUp:SetOpacity(1-timeLeft);
				self.popUp:SetSize(size, size)
				self.popUp:SetPosition(pos, pos)
				self.popUp:SetVisible(true)
				
			end
			
		
			if self.data["showoncd"] then

				self.icon:SetVisible(true)
				self.textBG:SetVisible(true)
				self.icon:SetOpacity(self.data["cdopacity"])
			
				if timeLeft < 1 then

					self.text:SetForeColor(self.tcolor)
					self.text:SetTextAlignment(self.talignment)
					self.text:SetFont(self.tfont)
					self.text:SetText(math.floor(timeLeft))
			
				elseif timeLeft < self.thresholdValue then
				
					self.text:SetForeColor(self.tcolor)
					self.text:SetTextAlignment(self.talignment)
					self.text:SetFont(self.tfont)
					self.text:SetText(math.floor(timeLeft))
				
				else
				
					self.text:SetForeColor(Turbine.UI.Color.White)
					self.text:SetTextAlignment(self.alignment)
					self.text:SetFont(self.font)
					self.text:SetText(math.floor(timeLeft))
				
				end
				
			else

				self.icon:SetVisible(false)
				self.textBG:SetVisible(false)
		
			end
			
		end

	else
	
		self:SetWantsUpdates(false)
	
	end

end

function Icon:Remove()

	self:SetVisible(false)

end
